;; Generated package description from sql-cassandra.el  -*- no-byte-compile: t -*-
(define-package "sql-cassandra" "0.2.1" "Cassandra support for sql.el" '((emacs "29")) :commit "2920f8c64e937904087f3636696501fb1cfe7acc" :url "https://elpa.gnu.org/packages/sql-cassandra.html" :authors '(("Filipp Gunbin" . "fgunbin@fastmail.fm")) :maintainer '("Filipp Gunbin" . "fgunbin@fastmail.fm") :keywords '("sql" "cassandra" "cql" "cqlsh"))
